@@ -1,4 +1,4 @@
-from msdm.core.problemclasses.pomdp import TabularPOMDP
+from msdm.core.pomdp import TabularPOMDP
 from msdm.core.distributions import DictDistribution
 class Tiger(TabularPOMDP):
     def __init__(self, coherence, discount_rate):
@@ -24,7 +24,7 @@ class Tiger(TabularPOMDP):
     def initial_state_dist(self):
         return DictDistribution.uniform(['left', 'right'])
 
-    def is_terminal(self, s):
+    def is_absorbing(self, s):
         return False
 
     def observation_dist(self, a, ns):
